#!/usr/bin/env python
#coding=utf-8

from airflow.models import DAG
from airflow.operators.bash_operator import BashOperator
from airflow.operators.subdag_operator import SubDagOperator
from subdags.idl_subdag import idl_subdag
import datetime
from config import *

default_args = {
    'owner' : 'wdc',
    'depends_on_past' : False,
    'start_date' : datetime.datetime(2017, 01, 01),
    'email' : ['wdc@huojutech.com'],
    'email_on_failure' : False,
    'email_on_retry': False,
    # 'retries' : 3,
    # 'retry_delay': datetime.timedelta(minutes=1),
}

DAG_NAME = 'fty_operator'

dag = DAG(
    dag_id=DAG_NAME,
    default_args=default_args,
    schedule_interval='0 1 * * *',
)

# 电视台收视率统计
tmp_ad_television_stat_task = BashOperator(
    task_id='tmp_ad_television_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_television_stat.py',
    dag=dag,
)

# 月份统计
tmp_ad_tv_station_mid_month_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_month_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_month_stat.py',
    dag=dag,
)

# 每月的数量，按电视台、剧场、类型分组
tmp_ad_tv_station_mid_quantity_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_quantity_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_quantity_stat.py',
    dag=dag,
)

# 平台近一年平均收视率统计
tmp_ad_tv_station_mid_avg_ratings_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_avg_ratings_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_avg_ratings_stat.py',
    dag=dag,
)

# 平台近一年去噪平均收视率
tmp_ad_tv_station_mid_avg_ratings_denoising_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_avg_ratings_denoising_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_avg_ratings_denoising_stat.py',
    dag=dag,
)

# 每月平均收视率统计
tmp_ad_tv_station_mid_ratings_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_ratings_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_ratings_stat.py',
    dag=dag,
)

# 每月平均收视指数统计
tmp_ad_tv_station_mid_ratings_index_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_ratings_index_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_ratings_index_stat.py',
    dag=dag,
)
tmp_ad_tv_station_mid_ratings_index_stat_task.set_upstream(tmp_ad_tv_station_mid_avg_ratings_stat_task)

# 每月去噪收视率统计
tmp_ad_tv_station_mid_ratings_denoising_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_ratings_denoising_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_ratings_denoising_stat.py',
    dag=dag,
)

# 每月去噪收视指数统计
tmp_ad_tv_station_mid_ratings_index_denoising_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_ratings_index_denoising_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_ratings_index_denoising_stat.py',
    dag=dag,
)
tmp_ad_tv_station_mid_ratings_index_denoising_stat_task.set_upstream(tmp_ad_tv_station_mid_avg_ratings_denoising_stat_task)

# 平台近一年数量统计
tmp_ad_tv_station_mid_type_stat_task = BashOperator(
    task_id='tmp_ad_tv_station_mid_type_stat',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ad_tv_station_mid_type_stat.py',
    dag=dag,
)
tmp_ad_tv_station_mid_type_stat_task.set_upstream(tmp_ad_tv_station_mid_quantity_stat_task)

# 类型热点统计
tmp_tv_station_type_hot_task = BashOperator(
    task_id='tmp_tv_station_type_hot',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_tv_station_type_hot.py',
    dag=dag,
)
tmp_tv_station_type_hot_task.set_upstream(tmp_ad_tv_station_mid_type_stat_task)

# 类型趋势统计
tmp_tv_station_type_trend_task = BashOperator(
    task_id='tmp_tv_station_type_trend',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_tv_station_type_trend.py',
    dag=dag,
)
tmp_tv_station_type_trend_task.set_upstream(tmp_ad_tv_station_mid_type_stat_task)

# 类型偏好统计
tmp_tv_station_type_preference_task = BashOperator(
    task_id='tmp_tv_station_type_preference',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_tv_station_type_preference.py',
    dag=dag,
)
tmp_tv_station_type_preference_task.set_upstream(tmp_tv_station_type_hot_task)
tmp_tv_station_type_preference_task.set_upstream(tmp_tv_station_type_trend_task)

# 收视指数偏好统计
tmp_tv_station_ratings_index_preference_task = BashOperator(
    task_id='tmp_tv_station_ratings_index_preference',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_tv_station_ratings_index_preference.py',
    dag=dag,
)
tmp_tv_station_ratings_index_preference_task.set_upstream(tmp_ad_tv_station_mid_ratings_index_stat_task)

# 去噪收视指数偏好统计
tmp_tv_station_ratings_index_denoising_preference_task = BashOperator(
    task_id='tmp_tv_station_ratings_index_denoising_preference',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_tv_station_ratings_index_denoising_preference.py',
    dag=dag,
)
tmp_tv_station_ratings_index_denoising_preference_task.set_upstream(tmp_ad_tv_station_mid_ratings_index_denoising_stat_task)

# 收视率趋势
tmp_ratings_current_trending_task = BashOperator(
    task_id='tmp_ratings_current_trending',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_ratings_current_trending.py',
    dag=dag,
)
tmp_ratings_current_trending_task.set_upstream(tmp_ad_tv_station_mid_ratings_stat_task)

# 排名趋势
tmp_rank_trending_task = BashOperator(
    task_id='tmp_rank_trending',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_rank_trending.py',
    dag=dag,
)
tmp_rank_trending_task.set_upstream(tmp_ad_tv_station_mid_ratings_stat_task)

# 电视台推荐
tmp_tv_station_recommend_task = BashOperator(
    task_id='tmp_tv_station_recommend',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_tv_station_recommend.py',
    dag=dag,
)
tmp_tv_station_recommend_task.set_upstream(tmp_ad_tv_station_mid_ratings_index_stat_task)
tmp_tv_station_recommend_task.set_upstream(tmp_tv_station_type_preference_task)
tmp_tv_station_recommend_task.set_upstream(tmp_tv_station_ratings_index_preference_task)

# 电视台去噪推荐
tmp_tv_station_recommend_denoising_task = BashOperator(
    task_id='tmp_tv_station_recommend_denoising',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_tv_station_recommend_denoising.py',
    dag=dag,
)
tmp_tv_station_recommend_denoising_task.set_upstream(tmp_ad_tv_station_mid_ratings_index_denoising_stat_task)
tmp_tv_station_recommend_denoising_task.set_upstream(tmp_tv_station_type_preference_task)
tmp_tv_station_recommend_denoising_task.set_upstream(tmp_tv_station_ratings_index_denoising_preference_task)

idl_task = SubDagOperator(
    task_id='idl_task',
    subdag=idl_subdag(DAG_NAME, 'idl_task', default_args),
    default_args=default_args,
    dag=dag,
)

# 设置月份下行依赖
tmp_ad_tv_station_mid_month_stat_task.set_downstream(tmp_ad_tv_station_mid_quantity_stat_task)
tmp_ad_tv_station_mid_month_stat_task.set_downstream(tmp_ad_tv_station_mid_avg_ratings_stat_task)
tmp_ad_tv_station_mid_month_stat_task.set_downstream(tmp_ad_tv_station_mid_avg_ratings_denoising_stat_task)
tmp_ad_tv_station_mid_month_stat_task.set_downstream(tmp_ad_tv_station_mid_ratings_stat_task)
tmp_ad_tv_station_mid_month_stat_task.set_downstream(tmp_ad_tv_station_mid_ratings_index_stat_task)
tmp_ad_tv_station_mid_month_stat_task.set_downstream(tmp_ad_tv_station_mid_ratings_denoising_stat_task)
tmp_ad_tv_station_mid_month_stat_task.set_downstream(tmp_ad_tv_station_mid_ratings_index_denoising_stat_task)
tmp_ad_tv_station_mid_month_stat_task.set_downstream(tmp_ad_tv_station_mid_type_stat_task)


idl_task.set_upstream(tmp_ad_tv_station_mid_ratings_stat_task)
idl_task.set_upstream(tmp_ad_tv_station_mid_ratings_index_stat_task)

tmp_tv_station_rank_task = BashOperator(
    task_id='tmp_tv_station_rank',
    bash_command='cd ' + SCRIPT_PATH + '; python tmp_tv_station_rank.py',
    dag=dag,
)
